@@ -12,7 +12,7 @@ dependencies {
 }
 // end::dependencies[]
 
-task<Copy>("copyLibs") {
+tasks.register<Copy>("copyLibs") {
     from(configurations.compileClasspath)
     into("$buildDir/libs")
 }
